@@ -36,7 +36,7 @@ foreach my $thr (0..$Threads) {
 }
 my ($screen_width,$screen_height)  = $framebuffer[0]->screen_dimensions();
 
-my $top = 16 * $Threads;
+my $top = 16 * $Threads; # Font height * # of threads
 
 $framebuffer[0]->cls('OFF');
 cls;
@@ -105,7 +105,7 @@ sub attract {
     my $gr   = (rand(10)/10);
     my $mode = int(rand(4));
     my $type = int(rand(13));
-    my $size = int(rand(7)) - 3;
+    my $size = int(rand(3));
     my $arc  = int(rand(3));
     my $filled = int(rand(2));
 
